California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 051 - SCHOOL BONDS. FUNDING FOR K-12 SCHOOL AND COMMUNITY COLLEGE FACILITIES. INITIATIVE STATUTORY AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1374469 | YES ON PROPOSITION 51 - CALIFORNIANS FOR QUALITY SCHOOLS, SPONSORED AND FUNDED BY COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE AND CALIFORNIA BUILDING INDUSTRY ASSOCIATION ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE, YES ON 51 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282321 | TORLAKSON'S INVEST IN CALIFORNIA A BALLOT MEASURE COMMITTEE TO SUPPORT PROPOSITION 51, SUPERINTENDENT TOM | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1382843 | CALIFORNIA TAXPAYERS AND EDUCATORS OPPOSED TO SPRAWL AND DEVELOPER ABUSE | OPPOSE